@@ -368,31 +368,30 @@ TRANSFORMATIONS = {
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-def ask_for_port():
+def ask_for_port(type):
     """\
     Show a list of ports and ask the user for a choice. To make selection
     easier on systems with long device names, also allow the input of an
     index.
     """
-    sys.stderr.write('\n--- Available ports:\n')
-    ports = []
-    for n, (port, desc, hwid) in enumerate(sorted(comports()), 1):
-        sys.stderr.write('--- {:2}: {:20} {!r}\n'.format(n, port, desc))
-        ports.append(port)
-    while True:
-        sys.stderr.write('--- Enter port index or full name: ')
-        port = raw_input('')
-        try:
-            index = int(port) - 1
-            if not 0 <= index < len(ports):
-                sys.stderr.write('--- Invalid index!\n')
-                continue
-        except ValueError:
-            pass
-        else:
-            port = ports[index]
-        return port
 
+    ports = []
+    portslist = comports()
+    if sys.platform == 'darwin':
+        if type == 'sniffer':
+            ports = [port.device for port in portslist if port.device == '/dev/cu.usbserial-MX0101']
+        elif type == 'proxy':
+            ports = [port.device for port in portslist if port.device == '/dev/cu.usbserial-MX0201']
+    else:
+        if type == 'sniffer':
+            ports = [port.device for port in portslist if port.serial_number == 'MX0101']
+        elif type == 'proxy':
+            ports = [port.device for port in portslist if port.serial_number == 'MX0201']
+    
+    if len(ports) == 0:
+      sys.stderr.write('ERROR: Dongle was not found!\n')
+      sys.exit(1)
+    return ports[0]
 
 class Miniterm(object):
     """\
@@ -520,7 +519,8 @@ class Miniterm(object):
         except serial.SerialException:
             self.alive = False
             self.console.cancel()
-            raise       # XXX handle instead of re-raise?
+            sys.stderr.write('\n\n\nERROR: Dongle was disconnected\n')
+            sys.exit(1)
 
     def writer(self):
         """\
@@ -826,7 +826,7 @@ class Miniterm(object):
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # default args can be used to override when calling main() from an other script
 # e.g to create a miniterm-my-device.py
-def main(default_port=None, default_baudrate=921600, default_rts=None, default_dtr=None, serial_instance=None):
+def main(default_type='sniffer', default_port=None, default_baudrate=921600, default_rts=None, default_dtr=None, serial_instance=None):
     """Command line tool, entry point"""
 
     import argparse
@@ -834,6 +834,12 @@ def main(default_port=None, default_baudrate=921600, default_rts=None, default_d
     parser = argparse.ArgumentParser(
         description='Miniterm - A simple terminal program for the serial port.')
 
+    parser.add_argument(
+        'type',
+        nargs='?',
+        help='Dongle Type',
+        default=default_type)
+
     parser.add_argument(
         'port',
         nargs='?',
@@ -979,7 +985,7 @@ def main(default_port=None, default_baudrate=921600, default_rts=None, default_d
         # no port given on command line -> ask user now
         if args.port is None or args.port == '-':
             try:
-                args.port = ask_for_port()
+                args.port = ask_for_port(args.type)
             except KeyboardInterrupt:
                 sys.stderr.write('\n')
                 parser.error('user aborted and port is not given')
